import { generatePlaywrightPath, isDev, isPackageValid, run } from '../util.mjs';
import { resolve } from 'path';
import { existsSync } from 'fs';
import { readFile, writeFile } from 'fs/promises';
import { createStoragePluginsSymlink as createStoragePluginsSymlink_1, createDevPluginsSymlink as createDevPluginsSymlink_1 } from '../utils/plugin-symlink.mjs';

var postinstall = (cli) => {
  const { APP_PACKAGE_ROOT } = process.env;
  cli.command("postinstall").allowUnknownOption().option("--skip-umi").action(async (options) => {
    generatePlaywrightPath(true);
    await createStoragePluginsSymlink_1();
    if (!isDev()) {
      return;
    }
    await createDevPluginsSymlink_1();
    const cwd = process.cwd();
    if (!existsSync(resolve(cwd, ".env")) && existsSync(resolve(cwd, ".env.example"))) {
      const content = await readFile(resolve(cwd, ".env.example"), "utf-8");
      await writeFile(resolve(cwd, ".env"), content, "utf-8");
    }
    if (!existsSync(resolve(cwd, ".env.test")) && existsSync(resolve(cwd, ".env.test.example"))) {
      const content = await readFile(resolve(cwd, ".env.test.example"), "utf-8");
      await writeFile(resolve(cwd, ".env.test"), content, "utf-8");
    }
    if (!isPackageValid("umi")) {
      return;
    }
    if (!options.skipUmi) {
      run("umi", ["generate", "tmp"], {
        stdio: "pipe",
        env: {
          APP_ROOT: `${APP_PACKAGE_ROOT}/client`
        }
      });
    }
  });
};

export { postinstall as default };
