import require$$0 from 'path';
import require$$1 from 'fs';

const { dirname, resolve } = require$$0;
const { readFile, writeFile, readdir, symlink, unlink, mkdir, stat } = require$$1.promises;
async function getStoragePluginNames(target) {
  const plugins = [];
  const items = await readdir(target);
  for (const item of items) {
    if (item.startsWith("@")) {
      const children = await getStoragePluginNames(resolve(target, item));
      plugins.push(
        ...children.map((child) => {
          return `${item}/${child}`;
        })
      );
    } else if (await fsExists(resolve(target, item, "package.json"))) {
      plugins.push(item);
    }
  }
  return plugins;
}
async function fsExists(path) {
  try {
    await stat(path);
    return true;
  } catch (error) {
    return false;
  }
}
async function createStoragePluginSymLink(pluginName) {
  const storagePluginsPath = resolve(process.cwd(), "storage/plugins");
  const nodeModulesPath = process.env.NODE_MODULES_PATH;
  try {
    if (pluginName.startsWith("@")) {
      const [orgName] = pluginName.split("/");
      if (!await fsExists(resolve(nodeModulesPath, orgName))) {
        await mkdir(resolve(nodeModulesPath, orgName), { recursive: true });
      }
    }
    const link = resolve(nodeModulesPath, pluginName);
    if (await fsExists(link)) {
      await unlink(link);
    }
    await symlink(resolve(storagePluginsPath, pluginName), link, "dir");
  } catch (error) {
    console.error(error);
  }
}
async function createStoragePluginsSymlink() {
  const storagePluginsPath = resolve(process.cwd(), "storage/plugins");
  if (!await fsExists(storagePluginsPath)) {
    return;
  }
  const pluginNames = await getStoragePluginNames(storagePluginsPath);
  await Promise.all(pluginNames.map((pluginName) => createStoragePluginSymLink(pluginName)));
}
var createStoragePluginsSymlink_1 = createStoragePluginsSymlink;
async function createDevPluginSymLink(pluginName) {
  const packagePluginsPath = resolve(process.cwd(), "packages/plugins");
  const nodeModulesPath = process.env.NODE_MODULES_PATH;
  try {
    if (pluginName.startsWith("@")) {
      const [orgName] = pluginName.split("/");
      if (!await fsExists(resolve(nodeModulesPath, orgName))) {
        await mkdir(resolve(nodeModulesPath, orgName), { recursive: true });
      }
    }
    const link = resolve(nodeModulesPath, pluginName);
    if (await fsExists(link)) {
      await unlink(link);
    }
    await symlink(resolve(packagePluginsPath, pluginName), link, "dir");
  } catch (error) {
    console.error(error);
  }
}
async function createDevPluginsSymlink() {
  const storagePluginsPath = resolve(process.cwd(), "packages/plugins");
  if (!await fsExists(storagePluginsPath)) {
    return;
  }
  const pluginNames = await getStoragePluginNames(storagePluginsPath);
  await Promise.all(pluginNames.map((pluginName) => createDevPluginSymLink(pluginName)));
}
var createDevPluginsSymlink_1 = createDevPluginsSymlink;

export { createDevPluginsSymlink_1 as createDevPluginsSymlink, createStoragePluginsSymlink_1 as createStoragePluginsSymlink };
